@@ -4,6 +4,6 @@ from ._coalesce import coalesce
 from ._consumer import Consumer
 from ._once import Once
 from ._predicate import Predicate
-from ._supplier import supplier_get, Supplier, ContextSupplier
+from ._supplier import ContextSupplier, Supplier, supplier_get
 
 __all__ = ['assure', 'coalesce', 'Consumer', 'Once', 'Predicate', 'supplier_get', 'Supplier', 'ContextSupplier']
