@@ -1,6 +1,6 @@
 
 from ._attribute import Attribute
-from ._color import Color, SgrColor, SgrColorName, LutColor, TrueColor
+from ._color import Color, LutColor, SgrColor, SgrColorName, TrueColor
 from ._style import Style, StyleManager
 
 __all__ = [
